All of lore.kernel.org
 help / color / mirror / Atom feed
From: Shu-Chun Weng via <qemu-devel@nongnu.org>
To: qemu-devel@nongnu.org, laurent@vivier.eu
Cc: Shu-Chun Weng <scw@google.com>
Subject: [PATCH v3 2/4] linux-user: add missing UDP get/setsockopt option
Date: Fri, 18 Dec 2020 11:32:11 -0800	[thread overview]
Message-ID: <20201218193213.3566856-3-scw@google.com> (raw)
In-Reply-To: <20201218193213.3566856-1-scw@google.com>

SOL_UDP manipulate options at UDP level. All six options currently defined
in linux source include/uapi/linux/udp.h take integer values.

Signed-off-by: Shu-Chun Weng <scw@google.com>
Reviewed-by: Laurent Vivier <laurent@vivier.eu>
---
v1 -> v2:
  Split out SOL_UDP into own patch.
  Updated do_print_sockopt().

v2 -> v3:
  Rebase to master on Dec 18, 2020

 linux-user/strace.c  | 6 ++++++
 linux-user/syscall.c | 7 +++++--
 2 files changed, 11 insertions(+), 2 deletions(-)

diff --git a/linux-user/strace.c b/linux-user/strace.c
index 227812c07e..64172de99d 100644
--- a/linux-user/strace.c
+++ b/linux-user/strace.c
@@ -7,6 +7,7 @@
 #include <sys/mount.h>
 #include <arpa/inet.h>
 #include <netinet/tcp.h>
+#include <netinet/udp.h>
 #include <linux/if_packet.h>
 #include <linux/netlink.h>
 #include <sched.h>
@@ -2644,6 +2645,11 @@ static void do_print_sockopt(const char *name, abi_long arg1)
         print_raw_param(TARGET_ABI_FMT_ld, optname, 0);
         print_pointer(optval, 0);
         break;
+    case SOL_UDP:
+        qemu_log("SOL_UDP,");
+        print_raw_param(TARGET_ABI_FMT_ld, optname, 0);
+        print_pointer(optval, 0);
+        break;
     case SOL_IP:
         qemu_log("SOL_IP,");
         print_raw_param(TARGET_ABI_FMT_ld, optname, 0);
diff --git a/linux-user/syscall.c b/linux-user/syscall.c
index be39cf8215..8576ad24b7 100644
--- a/linux-user/syscall.c
+++ b/linux-user/syscall.c
@@ -53,6 +53,7 @@
 //#include <sys/user.h>
 #include <netinet/ip.h>
 #include <netinet/tcp.h>
+#include <netinet/udp.h>
 #include <linux/wireless.h>
 #include <linux/icmp.h>
 #include <linux/icmpv6.h>
@@ -2177,7 +2178,8 @@ static abi_long do_setsockopt(int sockfd, int level, int optname,
 
     switch(level) {
     case SOL_TCP:
-        /* TCP options all take an 'int' value.  */
+    case SOL_UDP:
+        /* TCP and UDP options all take an 'int' value.  */
         if (optlen < sizeof(uint32_t))
             return -TARGET_EINVAL;
 
@@ -2825,7 +2827,8 @@ get_timeout:
         }
         break;
     case SOL_TCP:
-        /* TCP options all take an 'int' value.  */
+    case SOL_UDP:
+        /* TCP and UDP options all take an 'int' value.  */
     int_case:
         if (get_user_u32(len, optlen))
             return -TARGET_EFAULT;
-- 
2.29.2.684.gfbc64c5ab5-goog



  parent reply	other threads:[~2020-12-18 19:33 UTC|newest]

Thread overview: 7+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-12-18 19:32 [PATCH v3 0/4] fcntl and sockopt options Shu-Chun Weng via
2020-12-18 19:32 ` [PATCH v3 1/4] linux-user: Support F_ADD_SEALS and F_GET_SEALS fcntls Shu-Chun Weng via
2020-12-18 20:46   ` Laurent Vivier
2020-12-18 20:53   ` Laurent Vivier
2020-12-18 19:32 ` Shu-Chun Weng via [this message]
2020-12-18 19:32 ` [PATCH v3 3/4] linux-user: add missing IPv6 get/setsockopt option Shu-Chun Weng via
2020-12-18 19:32 ` [PATCH v3 4/4] linux-user: Add IPv6 options to do_print_sockopt() Shu-Chun Weng via

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20201218193213.3566856-3-scw@google.com \
    --to=qemu-devel@nongnu.org \
    --cc=laurent@vivier.eu \
    --cc=scw@google.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.